@@ -1,26 +1,11 @@
 /*
- * ark -- archiver for the KDE project
- *
- * Copyright (C) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
- * Copyright (C) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
- * Copyright (C) 2009-2012 Raphael Kubo da Costa <rakuco@FreeBSD.org>
- * Copyright (c) 2016 Vladyslav Batyrenko <mvlabat@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- */
+    SPDX-FileCopyrightText: 2007 Henrique Pinto <henrique.pinto@kdemail.net>
+    SPDX-FileCopyrightText: 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+    SPDX-FileCopyrightText: 2009-2012 Raphael Kubo da Costa <rakuco@FreeBSD.org>
+    SPDX-FileCopyrightText: 2016 Vladyslav Batyrenko <mvlabat@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "part.h"
 #include "ark_debug.h"
@@ -68,7 +53,6 @@
 #include <QStatusBar>
 #include <QPointer>
 #include <QSplitter>
-#include <QTimer>
 #include <QFileDialog>
 #include <QIcon>
 #include <QFileSystemWatcher>
@@ -1108,7 +1092,7 @@ void Part::slotWatchedFileModified(const QString& file)
 
     // Find the relative path of the file within the archive.
     QString relPath = file;
-    for (QTemporaryDir *tmpDir : qAsConst(m_tmpExtractDirList)) {
+    for (QTemporaryDir *tmpDir : std::as_const(m_tmpExtractDirList)) {
         relPath.remove(tmpDir->path()); //Remove tmpDir.
     }
     relPath.remove(0, 1); //Remove leading slash.
@@ -1454,11 +1438,11 @@ void Part::slotCutFiles()
     m_model->filesToMove = ArchiveModel::entryMap(filesForIndexes(selectedRows));
     qCDebug(ARK) << "Entries marked to cut:" << m_model->filesToMove.values();
     m_model->filesToCopy.clear();
-    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
+    for (const QModelIndex &row : std::as_const(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     m_cutIndexes = selectedRows;
-    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
+    for (const QModelIndex &row : std::as_const(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     updateActions();
@@ -1468,7 +1452,7 @@ void Part::slotCopyFiles()
 {
     m_model->filesToCopy = ArchiveModel::entryMap(filesForIndexes(addChildren(getSelectedIndexes())));
     qCDebug(ARK) << "Entries marked to copy:" << m_model->filesToCopy.values();
-    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
+    for (const QModelIndex &row : std::as_const(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     m_cutIndexes.clear();
@@ -1520,7 +1504,7 @@ void Part::slotPasteFiles()
             m_destination->setFullPath(m_destination->fullPath() + entryName);
         }
 
-        for (const Archive::Entry *entry : qAsConst(entriesWithoutChildren)) {
+        for (const Archive::Entry *entry : std::as_const(entriesWithoutChildren)) {
             if (entry->isDir() && m_destination->fullPath().startsWith(entry->fullPath())) {
                 KMessageBox::error(widget(),
                                    i18n("Folders can't be moved into themselves."),
